<?php

require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/user_input_handler.php';
require_once 'lib/user_input_handler_registry.php';
require_once 'lib/media_url.php';

class SundukMainCategoryListScreen extends AbstractPreloadedRegularScreen implements UserInputHandler {

    const ID = 'main_category_list';

    public static function get_media_url_str($group_id) {
        return MediaURL::encode(
                        array
                            (
                            'screen_id' => self::ID,
                            'group_id' => $group_id,
        ));
    }

    private $session;

    public function __construct($session, $folder_views) {
        parent::__construct(self::ID, $folder_views);
        $this->session = $session;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies) {
        return array
            (
            GUI_EVENT_KEY_ENTER => UserInputHandlerRegistry::create_action($this, 'enter'),
            GUI_EVENT_KEY_PLAY => UserInputHandlerRegistry::create_action($this, 'play'),
        );
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies) {

        $items = array();
        $items[] = array
            (
            PluginRegularFolderItem::media_url => MediaURL::encode(array('screen_id' => 'tv_group_list')),
            PluginRegularFolderItem::caption => 'Тв',
            PluginRegularFolderItem::view_item_params => array
                (
                ViewItemParams::icon_path => $this->session->get_icon('tv.png'),
                ViewItemParams::icon_sel_path => $this->session->get_icon('tv_selected.png'),
                ViewItemParams::item_detailed_icon_path => $this->session->get_icon('tv.png'),
            )
        );
        if ($this->session->get_services()->vod) {
            $items[] = array
                (
                PluginRegularFolderItem::media_url => MediaURL::encode(array('screen_id' => 'vod_root')),
                PluginRegularFolderItem::caption => 'Видеотека',
                PluginRegularFolderItem::view_item_params => array
                    (
                    ViewItemParams::icon_path => $this->session->get_icon('vod.png'),
                    ViewItemParams::icon_sel_path => $this->session->get_icon('vod_selected.png'),
                    ViewItemParams::item_detailed_icon_path => $this->session->get_icon('vod.png'),
                )
            );
        }
        $items[] = array
            (
            PluginRegularFolderItem::media_url => MediaURL::encode(array('screen_id' => 'setup')),
            PluginRegularFolderItem::caption => 'Настройки',
            PluginRegularFolderItem::view_item_params => array
                (
                ViewItemParams::icon_path => $this->session->get_icon('settings.png'),
                ViewItemParams::icon_sel_path => $this->session->get_icon('settings_selected.png'),
                ViewItemParams::item_detailed_icon_path => $this->session->get_icon('settings.png'),
            )
        );
        return $items;
    }

    public function get_handler_id() {
        return self::ID;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies) {
        if (MediaURL::decode($user_input->selected_media_url)->screen_id === 'tv_group_list') {
            return ActionFactory::tv_play();
        }
        else {
            return ActionFactory::open_folder($user_input->selected_media_url);
        }
    }

}
