<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/vod_series_list_screen.php';

class SundukVodSeriesListScreen extends VodSeriesListScreen implements UserInputHandler {
    
    private $vod;

    public function __construct(Vod $vod) {
        parent::__construct($vod);
        $this->vod = $vod;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }
    
    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        return array
        (
            GUI_EVENT_KEY_ENTER => UserInputHandlerRegistry::create_action($this, 'enter'),
            GUI_EVENT_KEY_PLAY  => UserInputHandlerRegistry::create_action($this, 'play'),
        );
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        if ($movie === null)
        {
            // TODO: dialog?
            return array();
        }

        $items = array();

        foreach ($movie->series_list as $series)
        {
            $items[] = array
            (
                PluginRegularFolderItem::media_url =>
                    SundukVodFormatListScreen::get_media_url_str($movie->id, $series->id),
                PluginRegularFolderItem::caption => $series->name . ($series->viewed?' (просмотрено)':''),
                PluginRegularFolderItem::view_item_params => array
                    (
                    ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                    ),
            );
        }

        return $items;
    }

    public function get_handler_id() {
        return self::ID;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies) {
        $media_url = MediaURL::decode($user_input->selected_media_url);
        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        $series = null;
        foreach($movie->series_list as $s){
            $series = $s;
            if($s->id == $media_url->series_id){
                break;
            }
        }
        if (count($series->formates) <= 1) {
            return ActionFactory::vod_play();
        }
        else {
            return ActionFactory::open_folder($user_input->selected_media_url);
        }
    }

}
